==> haskell-mintty-0.1.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mintty
version:              0.1.2
visibility:           public
id:                   mintty-0.1.2-5b08LLwS4rI2XuvUvOFfBx
key:                  mintty-0.1.2-5b08LLwS4rI2XuvUvOFfBx
license:              BSD-3-Clause
copyright:            (C) 2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/mintty
synopsis:
    A reliable way to detect the presence of a MinTTY console on Windows

description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.

    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.

category:             System
abi:                  a884be0c2c9f732571e7e0dffbcb1cdb
exposed:              True
exposed-modules:      System.Console.MinTTY
import-dirs:          /usr/lib/ghc-9.0.1/site-local/mintty-0.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/mintty-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/mintty-0.1.2
hs-libraries:         HSmintty-0.1.2-5b08LLwS4rI2XuvUvOFfBx
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html:         /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mintty-0.1.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mintty
version:              0.1.4
visibility:           public
id:                   mintty-0.1.4-AHmY1wu3LPK3fJSgahtSd9
key:                  mintty-0.1.4-AHmY1wu3LPK3fJSgahtSd9
license:              BSD-3-Clause
copyright:            (C) 2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/mintty
synopsis:
    A reliable way to detect the presence of a MinTTY console on Windows

description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.

    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.

category:             System
abi:                  c3fd825da8d9a831d15aeeb837806e83
exposed:              True
exposed-modules:      System.Console.MinTTY
import-dirs:          /usr/lib/ghc-9.0.2/site-local/mintty-0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mintty-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mintty
hs-libraries:         HSmintty-0.1.4-AHmY1wu3LPK3fJSgahtSd9
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html:         /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
